@@ -212,15 +212,32 @@ class half
 
     static short	convert (int i);
     static float	overflow ();
-    static bool		selftest ();
 
     unsigned short	_h;
 
-    static const uif		_toFloat[1 << 16];
-    static const unsigned short	_eLut[1 << 9];
-    static const bool		_itWorks;
+    //---------------------------------------------------
+    // Windows dynamic libraries don't like static
+    // member variables.
+    //---------------------------------------------------
+#ifndef OPENEXR_DLL
+    static const uif	        _toFloat[1 << 16];
+    static const unsigned short _eLut[1 << 9];
+#endif
 };
 
+#if defined(OPENEXR_DLL)
+    //--------------------------------------
+    // Lookup tables defined for Windows DLL
+    //--------------------------------------
+    #if defined(HALF_EXPORTS)
+        extern __declspec(dllexport) half::uif		_toFloat[1 << 16];
+        extern __declspec(dllexport) unsigned short	_eLut[1 << 9];
+    #else
+        extern __declspec(dllimport) half::uif		_toFloat[1 << 16];
+        extern __declspec(dllimport) unsigned short	_eLut[1 << 9];
+    #endif
+#endif
+
 
 //-----------
 // Stream I/O
@@ -240,17 +257,16 @@ void			printBits   (char  c[19], half  h);
 void			printBits   (char  c[35], float f);
 
 
-//-------
+//-------------------------------------------------------------------------
 // Limits
-//-------
-
-//----------------------------------------------------------------
-// Visual C++ will complain if these are not float constants,
-// but at least one other compiler (gcc 2.96) produces incorrect
+//
+// Visual C++ will complain if HALF_MIN, HALF_NRM_MIN etc. are not float
+// constants, but at least one other compiler (gcc 2.96) produces incorrect
 // results if they are.
-//----------------------------------------------------------------
+//-------------------------------------------------------------------------
+
+#if defined(PLATFORM_WINDOWS)
 
-#ifdef WIN32
 #define HALF_MIN	5.96046448e-08f	// Smallest positive half
 
 #define HALF_NRM_MIN	6.10351562e-05f	// Smallest positive normalized half
@@ -260,6 +276,7 @@ void			printBits   (char  c[35], float f);
 #define HALF_EPSILON	0.00097656f	// Smallest positive e for which
 					// half (1.0 + e) != half (1.0)
 #else
+
 #define HALF_MIN	5.96046448e-08	// Smallest positive half
 
 #define HALF_NRM_MIN	6.10351562e-05	// Smallest positive normalized half
@@ -268,7 +285,8 @@ void			printBits   (char  c[35], float f);
 
 #define HALF_EPSILON	0.00097656	// Smallest positive e for which
 					// half (1.0 + e) != half (1.0)
-#endif // WIN32
+#endif
+
 
 #define HALF_MANT_DIG	11		// Number of digits in mantissa
 					// (significand + hidden leading 1)
@@ -752,5 +770,6 @@ half::setBits (unsigned short bits)
     _h = bits;
 }
 
+#undef HALF_EXPORT_CONST
 
 #endif
