@@ -54,14 +54,18 @@
 #include <ImfEnvmapAttribute.h>
 #include <ImfFloatAttribute.h>
 #include <ImfIntAttribute.h>
+#include <ImfKeyCodeAttribute.h>
 #include <ImfLineOrderAttribute.h>
 #include <ImfMatrixAttribute.h>
 #include <ImfOpaqueAttribute.h>
 #include <ImfPreviewImageAttribute.h>
 #include <ImfStringAttribute.h>
 #include <ImfTileDescriptionAttribute.h>
+#include <ImfTimeCodeAttribute.h>
 #include <ImfVecAttribute.h>
 
+#include <Iex.h>
+
 #include <sstream>
 
 #include <stdlib.h>
@@ -74,45 +78,9 @@ using Imath::Box2i;
 using Imath::V2i;
 using Imath::V2f;
 
+
 namespace {
 
-
-void
-staticInitialize ()
-{
-    static bool initialized = false;
-
-    if (!initialized)
-    {
-	//
-	// One-time initialization -- register
-	// some predefined attribute types.
-	//
-	
-	Box2fAttribute::registerAttributeType();
-	Box2iAttribute::registerAttributeType();
-	ChannelListAttribute::registerAttributeType();
-	ChromaticitiesAttribute::registerAttributeType();
-	DoubleAttribute::registerAttributeType();
-	EnvmapAttribute::registerAttributeType();
-	FloatAttribute::registerAttributeType();
-	IntAttribute::registerAttributeType();
-	LineOrderAttribute::registerAttributeType();
-	M33fAttribute::registerAttributeType();
-	M44fAttribute::registerAttributeType();
-	PreviewImageAttribute::registerAttributeType();
-	StringAttribute::registerAttributeType();
-	TileDescriptionAttribute::registerAttributeType();
-	V2fAttribute::registerAttributeType();
-	V2iAttribute::registerAttributeType();
-	V3fAttribute::registerAttributeType();
-	V3iAttribute::registerAttributeType();
-
-	initialized = true;
-    }
-}
-
-
 void
 initialize (Header &header,
 	    const Box2i &displayWindow,
@@ -587,7 +555,7 @@ Header::sanityCheck (bool isTiled) const
     }
 
     //
-    // The screen window width must be greater than 0.
+    // The screen window width must not be less than 0.
     // The size of the screen window can vary over a wide
     // range (fish-eye lens to astronomical telescope),
     // so we can't limit the screen window width to a
@@ -836,7 +804,7 @@ Header::readFrom (IStream &is, int &version)
 	throw Iex::InputExc ("File is not an image file.");
     }
 
-    if (getVersion (version) != 1 && getVersion (version) != EXR_VERSION)
+    if (getVersion (version) != EXR_VERSION)
     {
 	THROW (Iex::InputExc, "Cannot read "
 			      "version " << getVersion (version) << " "
@@ -925,4 +893,42 @@ Header::readFrom (IStream &is, int &version)
 }
 
 
+void
+staticInitialize ()
+{
+    static bool initialized = false;
+
+    if (!initialized)
+    {
+	//
+	// One-time initialization -- register
+	// some predefined attribute types.
+	//
+	
+	Box2fAttribute::registerAttributeType();
+	Box2iAttribute::registerAttributeType();
+	ChannelListAttribute::registerAttributeType();
+	ChromaticitiesAttribute::registerAttributeType();
+	DoubleAttribute::registerAttributeType();
+	EnvmapAttribute::registerAttributeType();
+	FloatAttribute::registerAttributeType();
+	IntAttribute::registerAttributeType();
+	KeyCodeAttribute::registerAttributeType();
+	LineOrderAttribute::registerAttributeType();
+	M33fAttribute::registerAttributeType();
+	M44fAttribute::registerAttributeType();
+	PreviewImageAttribute::registerAttributeType();
+	StringAttribute::registerAttributeType();
+	TileDescriptionAttribute::registerAttributeType();
+	TimeCodeAttribute::registerAttributeType();
+	V2fAttribute::registerAttributeType();
+	V2iAttribute::registerAttributeType();
+	V3fAttribute::registerAttributeType();
+	V3iAttribute::registerAttributeType();
+
+	initialized = true;
+    }
+}
+
+
 } // namespace Imf
