@@ -53,9 +53,6 @@
 #include <assert.h>
 #include <algorithm>
 
-#if defined (PLATFORM_WIN32)
-#define for if(0) { } else for
-#endif
 
 using namespace std;
 using namespace Iex;
@@ -104,6 +101,13 @@ invalidCode ()
 }
 
 
+void
+invalidTableSize ()
+{
+    throw InputExc ("Error in Huffman-encoded data (invalid code table size).");
+}
+
+
 inline Int64
 hufLength (Int64 code)
 {
@@ -886,6 +890,9 @@ hufUncompress (const char compressed[],
     // int tableLength = readUInt (compressed + 8);
     int nBits = readUInt (compressed + 12);
 
+    if (im < 0 || im >= HUF_ENCSIZE || iM < 0 || iM >= HUF_ENCSIZE)
+	invalidTableSize();
+
     compressed += 20;
 
     AutoArray <Int64, HUF_ENCSIZE> freq;
