@@ -46,6 +46,7 @@
 #include <ImfRgbaYca.h>
 #include <ImfStandardAttributes.h>
 #include <ImathFun.h>
+#include <Iex.h>
 #include <string.h>
 #include <algorithm>
 
@@ -1168,6 +1169,13 @@ RgbaInputFile::readPixels (int scanLine)
 }
 
 
+bool
+RgbaInputFile::isComplete () const
+{
+    return _inputFile->isComplete();
+}
+
+
 const Header &
 RgbaInputFile::header () const
 {
