@@ -52,20 +52,31 @@
 #include <ImathQuat.h>
 #include <ImathEuler.h>
 #include <ImathExc.h>
+#include <ImathVec.h>
 #include <math.h>
 
 
+#ifdef OPENEXR_DLL
+    #ifdef IMATH_EXPORTS
+        #define IMATH_EXPORT_CONST extern __declspec(dllexport)
+    #else
+	#define IMATH_EXPORT_CONST extern __declspec(dllimport)
+    #endif
+#else
+    #define IMATH_EXPORT_CONST extern const
+#endif
+
+
 namespace Imath {
 
 //------------------
 // Identity matrices
 //------------------
 
-extern const M33f identity33f;
-extern const M33d identity33d;
-extern const M44f identity44f;
-extern const M44d identity44d;
-
+IMATH_EXPORT_CONST M33f identity33f;
+IMATH_EXPORT_CONST M44f identity44f;
+IMATH_EXPORT_CONST M33d identity33d;
+IMATH_EXPORT_CONST M44d identity44d;
 
 //----------------------------------------------------------------------
 // Extract scale, shear, rotation, and translation values from a matrix:
@@ -163,8 +174,16 @@ template <class T>  bool	extractSHRT
 				     Vec3<T> &h,
 				     Vec3<T> &r,
 				     Vec3<T> &t,
-				     bool exc = true,
-				     Eulerf::Order rOrder = Eulerf::XYZ);
+				     bool exc /*= true*/,
+				     typename Euler<T>::Order rOrder);
+
+template <class T>  bool	extractSHRT 
+                                    (const Matrix44<T> &mat,
+				     Vec3<T> &s,
+				     Vec3<T> &h,
+				     Vec3<T> &r,
+				     Vec3<T> &t,
+				     bool exc = true);
 
 template <class T>  bool	extractSHRT 
                                     (const Matrix44<T> &mat,
@@ -650,7 +669,6 @@ extractQuat (const Matrix44<T> &mat)
   return quat;
 }
 
-
 template <class T>
 bool 
 extractSHRT (const Matrix44<T> &mat,
@@ -659,7 +677,7 @@ extractSHRT (const Matrix44<T> &mat,
 	     Vec3<T> &r,
 	     Vec3<T> &t,
 	     bool exc /* = true */ ,
-	     Eulerf::Order rOrder /* = Eulerf::XYZ */ )
+	     typename Euler<T>::Order rOrder /* = Euler<T>::XYZ */ )
 {
     Matrix44<T> rot;
 
@@ -673,16 +691,27 @@ extractSHRT (const Matrix44<T> &mat,
     t.y = mat[3][1];
     t.z = mat[3][2];
 
-    if (rOrder != Eulerf::XYZ)
+    if (rOrder != Euler<T>::XYZ)
     {
-	Imath::Eulerf eXYZ (r, Imath::Eulerf::XYZ);
-	Imath::Eulerf e (eXYZ, rOrder);
+	Imath::Euler<T> eXYZ (r, Imath::Euler<T>::XYZ);
+	Imath::Euler<T> e (eXYZ, rOrder);
 	r = e.toXYZVector ();
     }
 
     return true;
 }
 
+template <class T>
+bool 
+extractSHRT (const Matrix44<T> &mat,
+	     Vec3<T> &s,
+	     Vec3<T> &h,
+	     Vec3<T> &r,
+	     Vec3<T> &t,
+	     bool exc)
+{
+    return extractSHRT(mat, s, h, r, t, exc, Imath::Euler<T>::XYZ);
+}
 
 template <class T>
 bool 
